<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2012.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	calendar_display_day_list_rh.cfm
Summary:
	Render Handler to render out the calendar day list view
ADF App:
	pt_calendar
Version:
	3.0.0
History:
	2011-07-14 - GAC - Created
	2012-10-19 - GAC - Modified to be rendered as a single view or as its own page using page mapping
--->
<cfscript>
	// This script MUST remain dynamic since the data and the generated HTML is modified with a URL parameters
	request.element.isStatic = 0;
	
	// Get the Configuration and Page Map Values
	appConfig = application.ptCalendar.getAppConfig();
	
	// Get the date/time CF display masks
	cfDateDisplayMask = application.ptCalendar.getDisplayCFdateMask(); // "M/D/YYYY" - DATE FORMAT FOR DISPLAY
	cfTimeDisplayMask = application.ptCalendar.getDisplayCFtimeMask(); // "h:mm tt" - TIME FORMAT FOR DISPLAY
	
	// initialize the link variables
	viewLinkData = StructNew();
	qParamDelimiter = "?";
	detailLink = cgi.script_name;
	dailyLink = cgi.script_name;
	
	// Set the Event Cache status from the configuration element
	useEventsCache = application.ptCalendar.getEventCacheStatus();
	
	// Get the items from the Display Properties Custom Element
	items = attributes.elementInfo.elementData.propertyValues;

	/* ** ptCalendar getRenderEventsData SETTINGS *** */
	//  -- THESE MUST ME INCLUDED AT THE TOP OF THE ptCalendar GRID/LIST RenderHandlers (before getRenderEventData)
	// - ptCalendar Date Range designation 
	viewRangeType = "Day"; 		// (Month/Week/Day)
	viewDisplayType = "List"; 	// (List - only option since this page contains the renderhandler code)
	
	// - ptCalendar EventsCache designation (generally this will be true. May need to set to false for debugging)
	// useEventsCache = false; // (true/false) - Use this as an override for the Global setting that is managed via the Configuration element
	
	/* ** getRenderEventsData SETTINGS *** */
	// ptCalendar date and data processing the calendar renderhandler return as CF query object
	//  -- THIS MUST BE INCLUDED AT THE TOP OF THE ptCalendar GRID/LIST RenderHandlers (after the getRenderEventData Settings)
	eventData = application.ptCalendar.calRenderController.getRenderEventData(
																	displayPropsArray=items
																	,viewRangeType=viewRangeType
																	,useEventsCache=useEventsCache
																);
	// Check if we have data to sort
	if ( ArrayLen(eventData) ) {
		// Sort the retArray
		eventData = application.ptCalendar.data.arrayOfStructsSortMultiKeys(
														aOfS=eventData
														,orderByKeyList="eventDate,AllDay DESC,StartTime"
													);
	}

	// Get the view link data structure
	if ( application.ptCalendar.viewPageMode EQ "Single" ) { 
		viewLinkData = application.ptCalendar.calRenderViewService.getCalViewPageStruct();
		qParamDelimiter = "&amp;";		
	}
	else {
		viewLinkData = application.ptCalendar.calPageMapDAO.getCalPageMapStruct();
	}

	if( structKeyExists(viewLinkData, "detailPage") and len(trim(viewLinkData.detailPage)) )
		detailLink = viewLinkData.detailPage;
	if( structKeyExists(viewLinkData, "dailyPage") and len(trim(viewLinkData.dailyPage)) )
		dailyLink = viewLinkData.dailyPage; 
	
	// set the nextPrevLink to the current view link
	nextPrevLink = dailyLink;
</cfscript>

<cfoutput>
<div class="calendarWrapper">

	<ul class="day-nav">
		<li><a href="#nextPrevLink##qParamDelimiter#clicked=1&day=#day(request.ptCalendar.yesterday)#&month=#month(request.ptCalendar.yesterday)#&year=#year(request.ptCalendar.yesterday)#">&lt;&lt; #dateFormat(request.ptCalendar.yesterday, "mmm dd")#</a></li>
		<li><a href="#nextPrevLink##qParamDelimiter#clicked=1&day=#day(request.ptCalendar.tomorrow)#&month=#month(request.ptCalendar.tomorrow)#&year=#year(request.ptCalendar.tomorrow)#">#dateFormat(request.ptCalendar.tomorrow, "mmm dd")# &gt;&gt;</a></li>
	</ul>
	
	<h2 class="day-header">Events for #request.ptCalendar.formattedDate#</h2>
	
	<cfif not arrayLen(eventData)>
		<h2 class="event-name">No events for today</h2>
	<cfelse>
		<cfloop from="1" to="#arrayLen(eventData)#" index="itm">
		
			<!--- // Build the event details link with URL params for the occurrence --->
			<!--- // There may be many Event Records with the the same calEventID (recurring events or an event with multiple date times) --->
			<!--- // - Each ocurrence of a recurring event gets a unique dtHashID --->
			<!--- // - Each "date/time" record for an event gets a unique dateTimeID --->
			<cfset linkParamsData = application.ptCalendar.calRenderService.buildEventDetailsLinksParams(eventDataStruct=eventData[itm])>
			<cfset eventDetailLink = application.ptCalendar.calRenderService.buildLinkParamURL(
																							linkURL=detailLink
																							,linkParamName=linkParamsData.UIDvarName
																							,linkParamValue=linkParamsData.UIDvalue
																							,urlParams=""
																						)>
			<cfset eventLayerID = linkParamsData.UIDstring>
			
			<!--- <cfset UID = "">
			<cfset UIDvarName = "">
			<cfset eventLayerID = "">
			<cfif StructKeyExists(eventData[itm],"dtHashID") AND LEN(TRIM(eventData[itm].dtHashID))>
				<cfset UID = eventData[itm].dtHashID>
				<cfset UIDvarName = "oid">
				<cfset eventDetailLink = detailLink & qParamDelimiter & UIDvarName & "=" & UID> 
			<cfelseif StructKeyExists(eventData[itm],"dateTimeID") AND LEN(TRIM(eventData[itm].dateTimeID))>
				<cfset UID = eventData[itm].dateTimeID>
				<cfset UIDvarName = "dtid">
				<cfset eventDetailLink = detailLink & qParamDelimiter & UIDvarName & "=" & UID>
			</cfif>
			<cfset eventLayerID = "eid-" & UIDvarName & "-" & UID> --->
			
			<!--- // TODO: Remove (temp fix) - temp fix for what??? --->
			<cfset eventLayerID = "">
			<cfif StructKeyExists(eventData[itm],"uniqueID") AND LEN(TRIM(eventData[itm].uniqueID))>
				<cfset eventLayerID = "eid-" & eventData[itm].uniqueID>
			</cfif> 
			
			<!--- // Build Category Icons and Text HTML Strings --->
			<cfset iconImgStr = "">
			<cfset catTextStr = "">
			<cfset categoryArray = ArrayNew(1)>
			<cfif StructKeyExists(eventData[itm],"Category") AND LEN(TRIM(eventData[itm].Category))>
				<!--- // Get Category Data based on Cat UUIDs --->
				<cfset categoryArray = application.ptCalendar.calEventCategoriesDAO.getEventCategories(uniqueID=eventData[itm].Category)>
				<!--- // Generate Category Icons HTML String --->
				<cfif ArrayLen(categoryArray)>
					<cfsavecontent variable="iconImgStr">
					<cfoutput>
						<div class="event-catIcons">
						<cfloop from="1" to="#ArrayLen(categoryArray)#" index="icn">
							<cfset catName = "">
							<cfset iconStruct = StructNew()>
							<cfif StructKeyExists(categoryArray[icn],"values")>	
								<cfif StructKeyExists(categoryArray[icn].values,"name") AND LEN(TRIM(categoryArray[icn].values.name))>
									<cfset catName = categoryArray[icn].values.name>
								</cfif>
								<cfif StructKeyExists(categoryArray[icn].values,"categoryIcon") AND LEN(TRIM(categoryArray[icn].values.categoryIcon))>
									<cfset iconStruct = application.ptCalendar.CSData.decipherCPIMAGE(categoryArray[icn].values.categoryIcon)>
									<cfif StructKeyExists(iconStruct,"RESOLVEDURL") AND StructKeyExists(iconStruct.RESOLVEDURL,"SERVERRELATIVE") AND LEN(TRIM(iconStruct.RESOLVEDURL.SERVERRELATIVE))>
									<img src="#iconStruct.RESOLVEDURL.SERVERRELATIVE#" class="toolTipeventIcon" border="0" alt="#catName#" />
									</cfif>
								</cfif>
							</cfif>
						</cfloop>
						</div>
					</cfoutput>
					</cfsavecontent>
					<!--- // Build Category Text Labels HTML String --->
					<cfsavecontent variable="catTextStr">
					<cfoutput>
						<cfloop from="1" to="#ArrayLen(categoryArray)#" index="cat">
							<cfif StructKeyExists(categoryArray[cat],"values") AND StructKeyExists(categoryArray[cat].values,"name") AND LEN(TRIM(categoryArray[cat].values.name))>
							<div class="event-catItems">- #categoryArray[cat].values.name#</div>
							</cfif>
						</cfloop>
					</cfoutput>
					</cfsavecontent>
				</cfif>
			</cfif>

			<div class="day-list-wrapper">
	
				<cfset eventTypeClassList = "">
				<cfif StructKeyExists(eventData[itm],"Category") AND LEN(TRIM(eventData[itm].Category))>
					<cfset eventTypeClassList = application.ptCalendar.calRenderService.buildEventTypeClassList(eventData[itm].Category)> 
				</cfif>
				
				<div id="#eventLayerID#" class="calEventLayer #eventTypeClassList#">
					
					<!--- // Build Time String for this event occurrence --->
					<cfsavecontent variable="timeStr">
					<cfoutput>
						<cfif StructKeyExists(eventData[itm],"AllDay") AND eventData[itm].AllDay EQ 1>
							[ALL DAY]
						<cfelseif StructKeyExists(eventData[itm],"startTime") AND LEN(TRIM(eventData[itm].startTime))>
							#timeFormat(eventData[itm].startTime, cfTimeDisplayMask)#<cfif StructKeyExists(eventData[itm],"endTime") AND LEN(TRIM(eventData[itm].endTime))> - #timeFormat(eventData[itm].endTime, cfTimeDisplayMask)#</cfif>
						</cfif>
					</cfoutput>
					</cfsavecontent>
	
					<!--- //Output Time String --->
					<cfif LEN(TRIM(timeStr))>
						<div class="event-header">#timeStr#</div><!--- class="event-time" --->
					</cfif>
					
					<!--- // Output Event Name and Detail Link with or without tooltip --->
					<div class="event-name">
						<cfif LEN(TRIM(iconImgStr))>#iconImgStr# </cfif>
						<a href='#eventDetailLink#'>#eventData[itm].title#</a>
						<cfif StructKeyExists(eventData[itm],"dateTimeID") AND StructKeyExists(eventData[itm],"dthashID")>
							<cfif LEN(TRIM(eventData[itm].dateTimeID)) AND LEN(TRIM(eventData[itm].dthashID))>
								&nbsp;<img alt="[B-R]" title="Broken Recurrence" width="9" height="8" src="/ADF/apps/pt_calendar/images/broken_recurr1.png" /><!--- [B-R] Broken Recurrence --->
							<cfelseif LEN(TRIM(eventData[itm].dthashID)) AND LEN(TRIM(eventData[itm].dateTimeID)) EQ 0>
								&nbsp;<img alt="[R]" title="Recurring Event" width="9" height="8" src="/ADF/apps/pt_calendar/images/recurrence1.png" /><!--- [R] - Recurrence --->
							</cfif>
						
								<!---<div><small>DateTimeID: #eventData[itm].dateTimeID#</small></div>
								<div><small>dtHashID: #eventData[itm].dtHashID#</small></div> --->
						</cfif>
						<!--- <div><small>EventID: #eventData[itm].uniqueID#</small></div>--->
					</div>
					
					<ul class="event-details">
					
					<!--- // Output Event Description --->
					<!--- <cfif StructKeyExists(eventData[itm],"description") AND LEN(TRIM(eventData[itm].description))>
						<li class="event-desc">Description: #eventData[itm].description#</li>
					</cfif>	 --->
					
					<!--- // Output Event Location --->
					<cfif StructKeyExists(eventData[itm],"location") AND LEN(TRIM(eventData[itm].location))>
						<li class="event-location">Location: <span>#eventData[itm].location#</span></li>
					</cfif>
								
					<!--- //Build Contact Info String --->
					<cfsavecontent variable="contactStr">
						<!--- <cfif StructKeyExists(eventData[itm],"useRequestorAsContact") AND LEN(TRIM(eventData[itm].useRequestorAsContact)) AND eventData[itm].useRequestorAsContact EQ 1>
							<cfif LEN(TRIM(eventData[itm].eventRequestorName))>
							<div class="event-contactName">#eventData[itm].eventRequestorName#</div>
							</cfif>	
							<cfif LEN(TRIM(eventData[itm].eventRequestorPhone))>
							<div class="event-contactPhone">#eventData[itm].eventRequestorPhone#</div>
							</cfif>
							<cfif LEN(TRIM(eventData[itm].eventRequestorEmail))>
							<div class="event-contactEmail"><a href="mailto:#eventData[itm].eventRequestorEmail#">#eventData[itm].eventRequestorEmail#</a></div>
							</cfif>
						<cfelse> --->
							<cfif StructKeyExists(eventData[itm],"contactName") AND LEN(TRIM(eventData[itm].contactName))>
							<div class="event-contactName"><strong>Name:</strong> #eventData[itm].contactName#</div>
							</cfif>	
							<cfif StructKeyExists(eventData[itm],"contactPhone") AND LEN(TRIM(eventData[itm].contactPhone))>
							<div class="event-contactPhone"><strong>Phone:</strong> #eventData[itm].contactPhone#</div>
							</cfif>
							<cfif StructKeyExists(eventData[itm],"contactEmail") AND LEN(TRIM(eventData[itm].contactEmail))>
							<div class="event-contactEmail"><strong>Email:</strong> <a href="mailto:#eventData[itm].contactEmail#">#eventData[itm].contactEmail#</a></div>
							</cfif>
						<!--- </cfif> --->
					</cfsavecontent>
					
					<!--- // Output Contact String --->
					<!--- <cfif LEN(TRIM(contactStr))>
						<li class="event-contact"><strong>Contact Information:</strong> <span>#contactStr#</span></li>
					</cfif> --->
					
					<!--- // Output URL String --->
					<!--- <cfif StructKeyExists(eventData[itm],"url") AND  LEN(TRIM(eventData[itm].url))>
						<li class="event-website"><strong>Web:</strong> <a href="#eventData[itm].url#">#eventData[itm].url#</a></li>
					</cfif> --->
				
					</ul>
						
					<!--- <cfif LEN(TRIM(eventData[itm].description))>
					<p class="event-desc">Description: #eventData[itm].description#</p>
					</cfif> --->
	
				</div>
			</div>
		</cfloop>
	</cfif>
</div>
</cfoutput>